@@ -1,6 +1,6 @@
 #extract a training set and test set from n samples
 #..using local variance :
-xtr_plan1 = function(data, knn, trcv) {
+xtr_plan1 = function(data, k, trcv) {
 
     #reduce dimension if too many :
     if (ncol(data) > 4) {
@@ -13,7 +13,7 @@ xtr_plan1 = function(data, knn, trcv) {
     n = nrow(data) ; locVar = rep(0.0,n)
     for (i in 1:n) {
         dists = sort( rowSums( ( t( t(data) - data[i,]) )^2 ) )
-        locVar[i] = mean(dists[2:(knn+1)])
+        locVar[i] = mean(dists[2:(k+1)])
     }
     srt = sort(locVar,index.return=TRUE)
 
@@ -23,7 +23,7 @@ xtr_plan1 = function(data, knn, trcv) {
 }
 
 #..using local densities :
-xtr_plan2 = function(data, knn, trcv) {
+xtr_plan2 = function(data, k, trcv) {
 
     #reduce dimension if too many :
     if (ncol(data) > 4) {
@@ -36,7 +36,7 @@ xtr_plan2 = function(data, knn, trcv) {
     n = nrow(data) ; locDists = rep(0.0,n)
 	for (i in 1:n) {
         dists = sort( rowSums( ( t( t(data) - data[i,]) )^2 ) )
-        locDists[i] = dists[knn+1]
+        locDists[i] = dists[k+1]
     }
 	srt = sort(locDists, index.return=TRUE)
 
